Class: Google::Apis::DatastreamV1alpha1::DiscoverConnectionProfileRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Overview

Request message for 'discover' ConnectionProfile request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoverConnectionProfileRequest

Returns a new instance of DiscoverConnectionProfileRequest.



324
325
326
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_profileGoogle::Apis::DatastreamV1alpha1::ConnectionProfile

An ad-hoc ConnectionProfile configuration. Corresponds to the JSON property connectionProfile



295
296
297
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 295

def connection_profile
  @connection_profile
end

#connection_profile_nameString

A reference to an existing ConnectionProfile. Corresponds to the JSON property connectionProfileName

Returns:

  • (String)


300
301
302
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 300

def connection_profile_name
  @connection_profile_name
end

#mysql_rdbmsGoogle::Apis::DatastreamV1alpha1::MysqlRdbms

MySQL database structure Corresponds to the JSON property mysqlRdbms



305
306
307
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 305

def mysql_rdbms
  @mysql_rdbms
end

#oracle_rdbmsGoogle::Apis::DatastreamV1alpha1::OracleRdbms

Oracle database structure. Corresponds to the JSON property oracleRdbms



310
311
312
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 310

def oracle_rdbms
  @oracle_rdbms
end

#recursion_depthFixnum

The number of hierarchy levels below the current level to be retrieved. Corresponds to the JSON property recursionDepth

Returns:

  • (Fixnum)


315
316
317
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 315

def recursion_depth
  @recursion_depth
end

#recursiveBoolean Also known as: recursive?

Whether to retrieve the full hierarchy of data objects (TRUE) or only the current level (FALSE). Corresponds to the JSON property recursive

Returns:

  • (Boolean)


321
322
323
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 321

def recursive
  @recursive
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



329
330
331
332
333
334
335
336
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 329

def update!(**args)
  @connection_profile = args[:connection_profile] if args.key?(:connection_profile)
  @connection_profile_name = args[:connection_profile_name] if args.key?(:connection_profile_name)
  @mysql_rdbms = args[:mysql_rdbms] if args.key?(:mysql_rdbms)
  @oracle_rdbms = args[:oracle_rdbms] if args.key?(:oracle_rdbms)
  @recursion_depth = args[:recursion_depth] if args.key?(:recursion_depth)
  @recursive = args[:recursive] if args.key?(:recursive)
end