Class: Google::Apis::DatastreamV1alpha1::Help

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Overview

Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Help

Returns a new instance of Help.



734
735
736
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

URL(s) pointing to additional information on handling the current error. Corresponds to the JSON property links



732
733
734
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 732

def links
  @links
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



739
740
741
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 739

def update!(**args)
  @links = args[:links] if args.key?(:links)
end