Class: Google::Apis::DatastreamV1alpha1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1255
1256
1257
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1214
1215
1216
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1214

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1219
1220
1221
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1219

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1224
1225
1226
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1224

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1232
1233
1234
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1232

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1238
1239
1240
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1238

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1243
1244
1245
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1243

def target
  @target
end

#validation_resultGoogle::Apis::DatastreamV1alpha1::ValidationResult

Contains the current validation results. Corresponds to the JSON property validationResult



1248
1249
1250
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1248

def validation_result
  @validation_result
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1253

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1260

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @validation_result = args[:validation_result] if args.key?(:validation_result)
  @verb = args[:verb] if args.key?(:verb)
end