Class: Google::Apis::DatastreamV1alpha1::OracleColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1alpha1::OracleColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb
Overview
Oracle Column.
Instance Attribute Summary collapse
-
#column_name ⇒ String
Column name.
-
#data_type ⇒ String
The Oracle data type.
-
#encoding ⇒ String
Column encoding.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OracleColumn
constructor
A new instance of OracleColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OracleColumn
Returns a new instance of OracleColumn.
1549 1550 1551 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_name ⇒ String
Column name.
Corresponds to the JSON property columnName
1505 1506 1507 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1505 def column_name @column_name end |
#data_type ⇒ String
The Oracle data type.
Corresponds to the JSON property dataType
1510 1511 1512 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1510 def data_type @data_type end |
#encoding ⇒ String
Column encoding.
Corresponds to the JSON property encoding
1515 1516 1517 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1515 def encoding @encoding end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
1520 1521 1522 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1520 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
1525 1526 1527 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1525 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
1531 1532 1533 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1531 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
1536 1537 1538 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1536 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
1541 1542 1543 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1541 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
1547 1548 1549 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1547 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1554 def update!(**args) @column_name = args[:column_name] if args.key?(:column_name) @data_type = args[:data_type] if args.key?(:data_type) @encoding = args[:encoding] if args.key?(:encoding) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |