Class: Google::Apis::DatastreamV1alpha1::PreconditionFailure
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1alpha1::PreconditionFailure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb
Overview
Describes what preconditions have failed. For example, if an RPC failed because it required the Terms of Service to be acknowledged, it could list the terms of service violation in the PreconditionFailure message.
Instance Attribute Summary collapse
-
#violations ⇒ Array<Google::Apis::DatastreamV1alpha1::PreconditionFailureViolation>
Describes all precondition violations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreconditionFailure
constructor
A new instance of PreconditionFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreconditionFailure
Returns a new instance of PreconditionFailure.
1753 1754 1755 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#violations ⇒ Array<Google::Apis::DatastreamV1alpha1::PreconditionFailureViolation>
Describes all precondition violations.
Corresponds to the JSON property violations
1751 1752 1753 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1751 def violations @violations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1758 1759 1760 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1758 def update!(**args) @violations = args[:violations] if args.key?(:violations) end |