Class: Google::Apis::DatastreamV1alpha1::PreconditionFailureViolation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Overview

A message type used to describe a single precondition failure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreconditionFailureViolation

Returns a new instance of PreconditionFailureViolation.



1788
1789
1790
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of how the precondition failed. Developers can use this description to understand how to fix the failure. For example: "Terms of service not accepted". Corresponds to the JSON property description

Returns:

  • (String)


1772
1773
1774
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1772

def description
  @description
end

#subjectString

The subject, relative to the type, that failed. For example, "google.com/cloud" relative to the "TOS" type would indicate which terms of service is being referenced. Corresponds to the JSON property subject

Returns:

  • (String)


1779
1780
1781
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1779

def subject
  @subject
end

#typeString

The type of PreconditionFailure. We recommend using a service-specific enum type to define the supported precondition violation subjects. For example, " TOS" for "Terms of Service violation". Corresponds to the JSON property type

Returns:

  • (String)


1786
1787
1788
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1786

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1793
1794
1795
1796
1797
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1793

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @subject = args[:subject] if args.key?(:subject)
  @type = args[:type] if args.key?(:type)
end