Class: Google::Apis::DatastreamV1alpha1::QuotaFailure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Overview

Describes how a quota check failed. For example if a daily limit was exceeded for the calling project, a service could respond with a QuotaFailure detail containing the project id and the description of the quota limit that was exceeded. If the calling project hasn't enabled the service in the developer console, then a service could respond with the project id and set service_disabled to true. Also see RetryInfo and Help types for other details about handling a quota failure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaFailure

Returns a new instance of QuotaFailure.



1897
1898
1899
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#violationsArray<Google::Apis::DatastreamV1alpha1::QuotaFailureViolation>

Describes all quota violations. Corresponds to the JSON property violations



1895
1896
1897
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1895

def violations
  @violations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1902
1903
1904
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1902

def update!(**args)
  @violations = args[:violations] if args.key?(:violations)
end