Class: Google::Apis::DatastreamV1alpha1::Route

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Overview

The Route resource is the child of the PrivateConnection resource. It used to define a route for a PrivateConnection setup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



1638
1639
1640
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The create time of the resource. Corresponds to the JSON property createTime

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1606

def create_time
  @create_time
end

#destination_addressString

Required. Destination address for connection Corresponds to the JSON property destinationAddress

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1611

def destination_address
  @destination_address
end

#destination_portFixnum

Destination port for connection Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


1616
1617
1618
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1616

def destination_port
  @destination_port
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1621
1622
1623
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1621

def display_name
  @display_name
end

#labelsHash<String,String>

Labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1626
1627
1628
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1626

def labels
  @labels
end

#nameString

Output only. The resource's name. Corresponds to the JSON property name

Returns:

  • (String)


1631
1632
1633
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1631

def name
  @name
end

#update_timeString

Output only. The update time of the resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


1636
1637
1638
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1636

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1643
1644
1645
1646
1647
1648
1649
1650
1651
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1643

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination_address = args[:destination_address] if args.key?(:destination_address)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end