Class: Google::Apis::DatastreamV1alpha1::Stream
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1alpha1::Stream
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb
Instance Attribute Summary collapse
-
#backfill_all ⇒ Google::Apis::DatastreamV1alpha1::BackfillAllStrategy
Backfill strategy to automatically backfill the Stream's objects.
-
#backfill_none ⇒ Google::Apis::DatastreamV1alpha1::BackfillNoneStrategy
Backfill strategy to disable automatic backfill for the Stream's objects.
-
#create_time ⇒ String
Output only.
-
#customer_managed_encryption_key ⇒ String
Immutable.
-
#destination_config ⇒ Google::Apis::DatastreamV1alpha1::DestinationConfig
The configuration of the stream destination.
-
#display_name ⇒ String
Required.
-
#errors ⇒ Array<Google::Apis::DatastreamV1alpha1::Error>
Output only.
-
#labels ⇒ Hash<String,String>
Labels.
-
#name ⇒ String
Output only.
-
#source_config ⇒ Google::Apis::DatastreamV1alpha1::SourceConfig
The configuration of the stream source.
-
#state ⇒ String
The state of the stream.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stream
constructor
A new instance of Stream.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stream
Returns a new instance of Stream.
2370 2371 2372 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backfill_all ⇒ Google::Apis::DatastreamV1alpha1::BackfillAllStrategy
Backfill strategy to automatically backfill the Stream's objects. Specific
objects can be excluded.
Corresponds to the JSON property backfillAll
2311 2312 2313 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2311 def backfill_all @backfill_all end |
#backfill_none ⇒ Google::Apis::DatastreamV1alpha1::BackfillNoneStrategy
Backfill strategy to disable automatic backfill for the Stream's objects.
Corresponds to the JSON property backfillNone
2316 2317 2318 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2316 def backfill_none @backfill_none end |
#create_time ⇒ String
Output only. The creation time of the stream.
Corresponds to the JSON property createTime
2321 2322 2323 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2321 def create_time @create_time end |
#customer_managed_encryption_key ⇒ String
Immutable. A reference to a KMS encryption key. If provided, it will be used
to encrypt the data. If left blank, data will be encrypted using an internal
Stream-specific encryption key provisioned through KMS.
Corresponds to the JSON property customerManagedEncryptionKey
2328 2329 2330 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2328 def customer_managed_encryption_key @customer_managed_encryption_key end |
#destination_config ⇒ Google::Apis::DatastreamV1alpha1::DestinationConfig
The configuration of the stream destination.
Corresponds to the JSON property destinationConfig
2333 2334 2335 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2333 def destination_config @destination_config end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
2338 2339 2340 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2338 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DatastreamV1alpha1::Error>
Output only. Errors on the Stream.
Corresponds to the JSON property errors
2343 2344 2345 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2343 def errors @errors end |
#labels ⇒ Hash<String,String>
Labels.
Corresponds to the JSON property labels
2348 2349 2350 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2348 def labels @labels end |
#name ⇒ String
Output only. The stream's name.
Corresponds to the JSON property name
2353 2354 2355 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2353 def name @name end |
#source_config ⇒ Google::Apis::DatastreamV1alpha1::SourceConfig
The configuration of the stream source.
Corresponds to the JSON property sourceConfig
2358 2359 2360 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2358 def source_config @source_config end |
#state ⇒ String
The state of the stream.
Corresponds to the JSON property state
2363 2364 2365 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2363 def state @state end |
#update_time ⇒ String
Output only. The last update time of the stream.
Corresponds to the JSON property updateTime
2368 2369 2370 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2368 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2375 def update!(**args) @backfill_all = args[:backfill_all] if args.key?(:backfill_all) @backfill_none = args[:backfill_none] if args.key?(:backfill_none) @create_time = args[:create_time] if args.key?(:create_time) @customer_managed_encryption_key = args[:customer_managed_encryption_key] if args.key?(:customer_managed_encryption_key) @destination_config = args[:destination_config] if args.key?(:destination_config) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @source_config = args[:source_config] if args.key?(:source_config) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |