Class: Google::Apis::DatastreamV1alpha1::DatastreamService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DatastreamV1alpha1::DatastreamService
- Defined in:
- lib/google/apis/datastream_v1alpha1/service.rb
Overview
Datastream API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://datastream.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_connection_profile(parent, connection_profile_object = nil, connection_profile_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a connection profile in a project and location.
-
#create_project_location_private_connection(parent, private_connection_object = nil, private_connection_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a private connectivity configuration.
-
#create_project_location_private_connection_route(parent, route_object = nil, request_id: nil, route_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a route for a private connectivity in a project and location.
-
#create_project_location_stream(parent, stream_object = nil, force: nil, request_id: nil, stream_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a stream.
-
#delete_project_location_connection_profile(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a connection profile..
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Empty
Deletes a long-running operation.
-
#delete_project_location_private_connection(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a private connectivity configuration.
-
#delete_project_location_private_connection_route(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a route.
-
#delete_project_location_stream(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a stream.
-
#discover_connection_profile(parent, discover_connection_profile_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::DiscoverConnectionProfileResponse
Use this method to discover a connection profile.
-
#fetch_project_location_static_ips(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::FetchStaticIpsResponse
The FetchStaticIps API call exposes the static IP addresses used by Datastream.
-
#fetch_stream_errors(stream, fetch_errors_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to fetch any errors associated with a stream.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Location
Gets information about a location.
-
#get_project_location_connection_profile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ConnectionProfile
Use this method to get details about a connection profile.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_private_connection(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::PrivateConnection
Use this method to get details about a private connectivity configuration.
-
#get_project_location_private_connection_route(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Route
Use this method to get details about a route.
-
#get_project_location_stream(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Stream
Use this method to get details about a stream.
-
#get_project_location_stream_object(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::StreamObject
Use this method to get details about a stream object.
-
#initialize ⇒ DatastreamService
constructor
A new instance of DatastreamService.
-
#list_project_location_connection_profiles(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListConnectionProfilesResponse
Use this method to list connection profiles created in a project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_private_connection_routes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListRoutesResponse
Use this method to list routes created for a private connectivity in a project and location.
-
#list_project_location_private_connections(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListPrivateConnectionsResponse
Use this method to list private connectivity configurations in a project and location.
-
#list_project_location_stream_objects(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListStreamObjectsResponse
Use this method to list the objects of a specific stream.
-
#list_project_location_streams(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListStreamsResponse
Use this method to list streams in a project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_connection_profile(name, connection_profile_object = nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to update the parameters of a connection profile.
-
#patch_project_location_stream(name, stream_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to update the configuration of a stream.
-
#start_project_location_stream_object_backfill_job(object, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::StartBackfillJobResponse
Starts backfill job for the specified stream object.
-
#stop_project_location_stream_object_backfill_job(object, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::StopBackfillJobResponse
Stops the backfill job for the specified stream object.
Constructor Details
#initialize ⇒ DatastreamService
Returns a new instance of DatastreamService.
47 48 49 50 51 52 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-datastream_v1alpha1', client_version: Google::Apis::DatastreamV1alpha1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 457 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:cancel', ) command.request_representation = Google::Apis::DatastreamV1alpha1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::DatastreamV1alpha1::Empty::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_connection_profile(parent, connection_profile_object = nil, connection_profile_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a connection profile in a project and location.
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 203 def create_project_location_connection_profile(parent, connection_profile_object = nil, connection_profile_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/connectionProfiles', ) command.request_representation = Google::Apis::DatastreamV1alpha1::ConnectionProfile::Representation command.request_object = connection_profile_object command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['connectionProfileId'] = connection_profile_id unless connection_profile_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_private_connection(parent, private_connection_object = nil, private_connection_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a private connectivity configuration.
616 617 618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 616 def create_project_location_private_connection(parent, private_connection_object = nil, private_connection_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/privateConnections', ) command.request_representation = Google::Apis::DatastreamV1alpha1::PrivateConnection::Representation command.request_object = private_connection_object command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['privateConnectionId'] = private_connection_id unless private_connection_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_private_connection_route(parent, route_object = nil, request_id: nil, route_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a route for a private connectivity in a project and location.
790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 790 def create_project_location_private_connection_route(parent, route_object = nil, request_id: nil, route_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/routes', ) command.request_representation = Google::Apis::DatastreamV1alpha1::Route::Representation command.request_object = route_object command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['routeId'] = route_id unless route_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_stream(parent, stream_object = nil, force: nil, request_id: nil, stream_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to create a stream.
962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 962 def create_project_location_stream(parent, stream_object = nil, force: nil, request_id: nil, stream_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/streams', ) command.request_representation = Google::Apis::DatastreamV1alpha1::Stream::Representation command.request_object = stream_object command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['streamId'] = stream_id unless stream_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_connection_profile(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a connection profile..
248 249 250 251 252 253 254 255 256 257 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 248 def delete_project_location_connection_profile(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
492 493 494 495 496 497 498 499 500 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 492 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Empty::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_private_connection(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a private connectivity configuration.
664 665 666 667 668 669 670 671 672 673 674 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 664 def delete_project_location_private_connection(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_private_connection_route(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a route.
835 836 837 838 839 840 841 842 843 844 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 835 def delete_project_location_private_connection_route(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_stream(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to delete a stream.
1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1009 def delete_project_location_stream(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#discover_connection_profile(parent, discover_connection_profile_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::DiscoverConnectionProfileResponse
Use this method to discover a connection profile. The discover API call exposes the data objects and metadata belonging to the profile. Typically, a request returns children data objects under a parent data object that's optionally supplied in the request.
284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 284 def discover_connection_profile(parent, discover_connection_profile_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/connectionProfiles:discover', ) command.request_representation = Google::Apis::DatastreamV1alpha1::DiscoverConnectionProfileRequest::Representation command.request_object = discover_connection_profile_request_object command.response_representation = Google::Apis::DatastreamV1alpha1::DiscoverConnectionProfileResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::DiscoverConnectionProfileResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#fetch_project_location_static_ips(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::FetchStaticIpsResponse
The FetchStaticIps API call exposes the static IP addresses used by Datastream.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 80 def fetch_project_location_static_ips(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}:fetchStaticIps', ) command.response_representation = Google::Apis::DatastreamV1alpha1::FetchStaticIpsResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::FetchStaticIpsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#fetch_stream_errors(stream, fetch_errors_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to fetch any errors associated with a stream.
1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1041 def fetch_stream_errors(stream, fetch_errors_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+stream}:fetchErrors', ) command.request_representation = Google::Apis::DatastreamV1alpha1::FetchErrorsRequest::Representation command.request_object = fetch_errors_request_object command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['stream'] = stream unless stream.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Location
Gets information about a location.
112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 112 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Location::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_connection_profile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ConnectionProfile
Use this method to get details about a connection profile.
316 317 318 319 320 321 322 323 324 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 316 def get_project_location_connection_profile(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ConnectionProfile::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ConnectionProfile command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
523 524 525 526 527 528 529 530 531 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 523 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_private_connection(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::PrivateConnection
Use this method to get details about a private connectivity configuration.
696 697 698 699 700 701 702 703 704 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 696 def get_project_location_private_connection(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::PrivateConnection::Representation command.response_class = Google::Apis::DatastreamV1alpha1::PrivateConnection command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_private_connection_route(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Route
Use this method to get details about a route.
866 867 868 869 870 871 872 873 874 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 866 def get_project_location_private_connection_route(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Route::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Route command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_stream(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Stream
Use this method to get details about a stream.
1073 1074 1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1073 def get_project_location_stream(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::Stream::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Stream command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_stream_object(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::StreamObject
Use this method to get details about a stream object.
1208 1209 1210 1211 1212 1213 1214 1215 1216 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1208 def get_project_location_stream_object(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1alpha1::StreamObject::Representation command.response_class = Google::Apis::DatastreamV1alpha1::StreamObject command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_profiles(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListConnectionProfilesResponse
Use this method to list connection profiles created in a project and location.
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 359 def list_project_location_connection_profiles(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/connectionProfiles', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ListConnectionProfilesResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ListConnectionProfilesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 568 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/operations', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ListOperationsResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_private_connection_routes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListRoutesResponse
Use this method to list routes created for a private connectivity in a project and location.
909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 909 def list_project_location_private_connection_routes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/routes', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ListRoutesResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ListRoutesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_private_connections(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListPrivateConnectionsResponse
Use this method to list private connectivity configurations in a project and location.
741 742 743 744 745 746 747 748 749 750 751 752 753 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 741 def list_project_location_private_connections(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/privateConnections', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ListPrivateConnectionsResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ListPrivateConnectionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_stream_objects(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListStreamObjectsResponse
Use this method to list the objects of a specific stream.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1246 def list_project_location_stream_objects(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/objects', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ListStreamObjectsResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ListStreamObjectsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_streams(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListStreamsResponse
Use this method to list streams in a project and location.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1115 def list_project_location_streams(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/streams', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ListStreamsResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ListStreamsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 155 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/locations', ) command.response_representation = Google::Apis::DatastreamV1alpha1::ListLocationsResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_connection_profile(name, connection_profile_object = nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to update the parameters of a connection profile.
414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 414 def patch_project_location_connection_profile(name, connection_profile_object = nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::DatastreamV1alpha1::ConnectionProfile::Representation command.request_object = connection_profile_object command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_stream(name, stream_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::Operation
Use this method to update the configuration of a stream.
1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1172 def patch_project_location_stream(name, stream_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::DatastreamV1alpha1::Stream::Representation command.request_object = stream_object command.response_representation = Google::Apis::DatastreamV1alpha1::Operation::Representation command.response_class = Google::Apis::DatastreamV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_project_location_stream_object_backfill_job(object, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::StartBackfillJobResponse
Starts backfill job for the specified stream object.
1278 1279 1280 1281 1282 1283 1284 1285 1286 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1278 def start_project_location_stream_object_backfill_job(object, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+object}:startBackfillJob', ) command.response_representation = Google::Apis::DatastreamV1alpha1::StartBackfillJobResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::StartBackfillJobResponse command.params['object'] = object unless object.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_project_location_stream_object_backfill_job(object, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1alpha1::StopBackfillJobResponse
Stops the backfill job for the specified stream object.
1308 1309 1310 1311 1312 1313 1314 1315 1316 |
# File 'lib/google/apis/datastream_v1alpha1/service.rb', line 1308 def stop_project_location_stream_object_backfill_job(object, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+object}:stopBackfillJob', ) command.response_representation = Google::Apis::DatastreamV1alpha1::StopBackfillJobResponse::Representation command.response_class = Google::Apis::DatastreamV1alpha1::StopBackfillJobResponse command.params['object'] = object unless object.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |