Class: Google::Apis::DatastreamV1alpha1::OracleColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Overview

Oracle Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleColumn

Returns a new instance of OracleColumn.



1323
1324
1325
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_nameString

Column name. Corresponds to the JSON property columnName

Returns:

  • (String)


1279
1280
1281
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1279

def column_name
  @column_name
end

#data_typeString

The Oracle data type. Corresponds to the JSON property dataType

Returns:

  • (String)


1284
1285
1286
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1284

def data_type
  @data_type
end

#encodingString

Column encoding. Corresponds to the JSON property encoding

Returns:

  • (String)


1289
1290
1291
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1289

def encoding
  @encoding
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


1294
1295
1296
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1294

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


1299
1300
1301
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1299

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


1305
1306
1307
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1305

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


1310
1311
1312
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1310

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


1315
1316
1317
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1315

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


1321
1322
1323
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1321

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1328

def update!(**args)
  @column_name = args[:column_name] if args.key?(:column_name)
  @data_type = args[:data_type] if args.key?(:data_type)
  @encoding = args[:encoding] if args.key?(:encoding)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end