Class: Google::Apis::DatastreamV1alpha1::Stream

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stream

Returns a new instance of Stream.



1867
1868
1869
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backfill_allGoogle::Apis::DatastreamV1alpha1::BackfillAllStrategy

Backfill strategy to automatically backfill the Stream's objects. Specific objects can be excluded. Corresponds to the JSON property backfillAll



1808
1809
1810
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1808

def backfill_all
  @backfill_all
end

#backfill_noneGoogle::Apis::DatastreamV1alpha1::BackfillNoneStrategy

Backfill strategy to disable automatic backfill for the Stream's objects. Corresponds to the JSON property backfillNone



1813
1814
1815
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1813

def backfill_none
  @backfill_none
end

#create_timeString

Output only. The creation time of the stream. Corresponds to the JSON property createTime

Returns:

  • (String)


1818
1819
1820
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1818

def create_time
  @create_time
end

#customer_managed_encryption_keyString

Immutable. A reference to a KMS encryption key. If provided, it will be used to encrypt the data. If left blank, data will be encrypted using an internal Stream-specific encryption key provisioned through KMS. Corresponds to the JSON property customerManagedEncryptionKey

Returns:

  • (String)


1825
1826
1827
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1825

def customer_managed_encryption_key
  @customer_managed_encryption_key
end

#destination_configGoogle::Apis::DatastreamV1alpha1::DestinationConfig

The configuration of the stream destination. Corresponds to the JSON property destinationConfig



1830
1831
1832
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1830

def destination_config
  @destination_config
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1835
1836
1837
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1835

def display_name
  @display_name
end

#errorsArray<Google::Apis::DatastreamV1alpha1::Error>

Output only. Errors on the Stream. Corresponds to the JSON property errors



1840
1841
1842
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1840

def errors
  @errors
end

#labelsHash<String,String>

Labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1845
1846
1847
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1845

def labels
  @labels
end

#nameString

Output only. The stream's name. Corresponds to the JSON property name

Returns:

  • (String)


1850
1851
1852
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1850

def name
  @name
end

#source_configGoogle::Apis::DatastreamV1alpha1::SourceConfig

The configuration of the stream source. Corresponds to the JSON property sourceConfig



1855
1856
1857
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1855

def source_config
  @source_config
end

#stateString

The state of the stream. Corresponds to the JSON property state

Returns:

  • (String)


1860
1861
1862
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1860

def state
  @state
end

#update_timeString

Output only. The last update time of the stream. Corresponds to the JSON property updateTime

Returns:

  • (String)


1865
1866
1867
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1865

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1872

def update!(**args)
  @backfill_all = args[:backfill_all] if args.key?(:backfill_all)
  @backfill_none = args[:backfill_none] if args.key?(:backfill_none)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_managed_encryption_key = args[:customer_managed_encryption_key] if args.key?(:customer_managed_encryption_key)
  @destination_config = args[:destination_config] if args.key?(:destination_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @source_config = args[:source_config] if args.key?(:source_config)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end