Class: Google::Apis::DatastreamV1alpha1::StreamObject
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1alpha1::StreamObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb
Overview
A specific stream object (e.g a specific DB table).
Instance Attribute Summary collapse
-
#backfill_job ⇒ Google::Apis::DatastreamV1alpha1::BackfillJob
Represents a backfill job on a specific stream object.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#errors ⇒ Array<Google::Apis::DatastreamV1alpha1::Error>
Output only.
-
#name ⇒ String
Output only.
-
#source_object ⇒ Google::Apis::DatastreamV1alpha1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamObject
constructor
A new instance of StreamObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamObject
Returns a new instance of StreamObject.
2430 2431 2432 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backfill_job ⇒ Google::Apis::DatastreamV1alpha1::BackfillJob
Represents a backfill job on a specific stream object.
Corresponds to the JSON property backfillJob
2398 2399 2400 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2398 def backfill_job @backfill_job end |
#create_time ⇒ String
Output only. The creation time of the object.
Corresponds to the JSON property createTime
2403 2404 2405 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2403 def create_time @create_time end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
2408 2409 2410 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2408 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DatastreamV1alpha1::Error>
Output only. Active errors on the object.
Corresponds to the JSON property errors
2413 2414 2415 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2413 def errors @errors end |
#name ⇒ String
Output only. The object's name.
Corresponds to the JSON property name
2418 2419 2420 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2418 def name @name end |
#source_object ⇒ Google::Apis::DatastreamV1alpha1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Corresponds to the JSON property sourceObject
2423 2424 2425 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2423 def source_object @source_object end |
#update_time ⇒ String
Output only. The last update time of the object.
Corresponds to the JSON property updateTime
2428 2429 2430 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2428 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2435 2436 2437 2438 2439 2440 2441 2442 2443 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 2435 def update!(**args) @backfill_job = args[:backfill_job] if args.key?(:backfill_job) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @name = args[:name] if args.key?(:name) @source_object = args[:source_object] if args.key?(:source_object) @update_time = args[:update_time] if args.key?(:update_time) end |