Class: Google::Apis::DatastreamV1alpha1::StreamObject
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1alpha1::StreamObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1alpha1/classes.rb,
lib/google/apis/datastream_v1alpha1/representations.rb,
lib/google/apis/datastream_v1alpha1/representations.rb
Overview
A specific stream object (e.g a specific DB table).
Instance Attribute Summary collapse
-
#backfill_job ⇒ Google::Apis::DatastreamV1alpha1::BackfillJob
Represents a backfill job on a specific stream object.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#errors ⇒ Array<Google::Apis::DatastreamV1alpha1::Error>
Output only.
-
#name ⇒ String
Output only.
-
#source_object ⇒ Google::Apis::DatastreamV1alpha1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamObject
constructor
A new instance of StreamObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamObject
Returns a new instance of StreamObject.
1927 1928 1929 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backfill_job ⇒ Google::Apis::DatastreamV1alpha1::BackfillJob
Represents a backfill job on a specific stream object.
Corresponds to the JSON property backfillJob
1895 1896 1897 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1895 def backfill_job @backfill_job end |
#create_time ⇒ String
Output only. The creation time of the object.
Corresponds to the JSON property createTime
1900 1901 1902 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1900 def create_time @create_time end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
1905 1906 1907 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1905 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DatastreamV1alpha1::Error>
Output only. Active errors on the object.
Corresponds to the JSON property errors
1910 1911 1912 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1910 def errors @errors end |
#name ⇒ String
Output only. The object's name.
Corresponds to the JSON property name
1915 1916 1917 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1915 def name @name end |
#source_object ⇒ Google::Apis::DatastreamV1alpha1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Corresponds to the JSON property sourceObject
1920 1921 1922 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1920 def source_object @source_object end |
#update_time ⇒ String
Output only. The last update time of the object.
Corresponds to the JSON property updateTime
1925 1926 1927 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1925 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1932 1933 1934 1935 1936 1937 1938 1939 1940 |
# File 'lib/google/apis/datastream_v1alpha1/classes.rb', line 1932 def update!(**args) @backfill_job = args[:backfill_job] if args.key?(:backfill_job) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @name = args[:name] if args.key?(:name) @source_object = args[:source_object] if args.key?(:source_object) @update_time = args[:update_time] if args.key?(:update_time) end |